/*
 *   ORXONOX - the hottest 3D action shooter ever to exist
 *                    > www.orxonox.net <
 *
 *
 *   License notice:
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License
 *   as published by the Free Software Foundation; either version 2
 *   of the License, or (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program; if not, write to the Free Software
 *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 *   Author:
 *      Florian Zinggeler
 *
 */

#include "FlappyOrxHUDinfo.h"

#include "core/CoreIncludes.h"
#include "core/XMLPort.h"
#include "util/Convert.h"
#include "FlappyOrx.h"

namespace orxonox
{
    RegisterClass(FlappyOrxHUDinfo);

    FlappyOrxHUDinfo::FlappyOrxHUDinfo(Context* context) : OverlayText(context)
    {
        RegisterObject(FlappyOrxHUDinfo);

        this->FlappyOrxGame = nullptr;
        this->bShowLives_ = false;
        this->bShowLevel_ = true;
        this->bShowPoints_ = false;
        this->bShowMultiplier_ = false;
    }

    void FlappyOrxHUDinfo::XMLPort(Element& xmlelement, XMLPort::Mode mode)
    {
        SUPER(FlappyOrxHUDinfo, XMLPort, xmlelement, mode);

        XMLPortParam(FlappyOrxHUDinfo, "showlives",     setShowLives,     getShowLives,     xmlelement, mode).defaultValues(false);
        XMLPortParam(FlappyOrxHUDinfo, "showPoints",     setShowPoints,     getShowPoints,     xmlelement, mode).defaultValues(false);
       
    
    }

    void FlappyOrxHUDinfo::tick(float dt)
    {
        SUPER(FlappyOrxHUDinfo, tick, dt);

        if (this->FlappyOrxGame)
        {
            // if (this->bShowLives_)  //preperation for easy mode
            // {
            //     const std::string& lives = multi_cast<std::string>(this->InvaderGame->getLives());
            //     this->setCaption(lives);
            // }
            if(this->bShowPoints_)
            {
                const std::string& points = multi_cast<std::string>(this->FlappyOrxGame->getPoints());
                if (this->FlappyOrxGame->lives <= 0)
                {
                    setTextSize(0.2);
                    setPosition(Vector2(0.1, 0.02));
                    this->setCaption("Final score:\n" + points);
                    this->setColour(ColourValue(1, 0, 0, 1));
                }
                else
                {
                    setTextSize(0.04);
                    setPosition(Vector2(0.14, 0.02));
                    this->setColour(ColourValue(1, 1, 1, 1));
                    this->setCaption(points);
                }
            }
           
        }
    }

    void FlappyOrxHUDinfo::changedOwner()
    {
        SUPER(FlappyOrxHUDinfo, changedOwner);

        if (this->getOwner() && this->getOwner()->getGametype())
        {
            this->FlappyOrxGame = orxonox_cast<FlappyOrx*>(this->getOwner()->getGametype());
        }
        else
        {
            this->FlappyOrxGame = nullptr;
        }
    }
}
